import sys
from gi.repository import Gtk
from window import TahrirWindow
from document import Document

class TahrirApp(Gtk.Application):
    def __init__(self):
        Gtk.Application.__init__(self)
        self.documents = []
        self.docsCount = 0
        self.untitledDocs = 0

    def newDocument(self, filename):
        doc = Document()
        if(filename != None):
            doc.setFilename(filename)
            doc.fetchTitle()
            doc.fetchContent()
        self.docsCount += 1
        title = doc.get_title()
        doc.set_modified(False)
        self._win.notebook.append_page(doc, Gtk.Label(_(title)))
        self._win.toolbar.documentsBox.append(str(self.docs_count),title)
        self._win.toolbar.documentsBox.set_active_id(str(self.docs_count))
        self._win.notebook.set_current_page(-1)
        self._win.notebook.show_all()

    def openDialog(self):
        d = Gtk.FileChooserDialog('Open file', self, Gtk.FileChooserAction.OPEN, ("Cance", 0, "Open", 1))
        d.set_select_multiple(True)
        d.set_default_response(1)
        if d.run() == 1:
            filenames = d.get_filenames()
            for f in filenames:
                self.new_document(f)
        d.destroy()

    def saveRequest(self):
        doc = self.get_current_document()
        filename = doc.get_filename()
        if filename != None:
            doc.save()
        elif filename == None:
            d = Gtk.FileChooserDialog('Save '+doc.get_title(), self, Gtk.FileChooserAction.SAVE, ("Cance", 0, "Save", 1))
            d.set_default_response(1)
            d.set_do_overwrite_confirmation(True)
            if d.run() == 1:
                doc.set_filename(d.get_filename())
                doc.save()
            d.destroy()

    def switchView(self, view_id):
        self.notebook.set_current_page(view_id)
        self.notebook.show_all()

    def getCurrentDocument(self):
        current_id = self.notebook.get_current_page()
        return self.documents[current_id]

    def do_startup(self):
        Gtk.Application.do_startup(self)

    def do_activate(self):
        self._win = TahrirWindow(self)
        self._win.present()

if __name__ == '__main__':
    app = TahrirApp()
    r = app.run(sys.argv)
    sys.exit(r)
